@@ -2,7 +2,8 @@ from __future__ import annotations
 
 from typing import Any, Callable, Dict, List, Tuple, Union
 
-from quaterion_models.types import CollateFnType
+from quaterion_models.types import CollateFnType, MetaExtractorFnType
+from quaterion_models.utils.meta import merge_meta
 
 from quaterion.dataset import SimilarityGroupSample, SimilarityPairSample
 
@@ -22,10 +23,14 @@ class TrainCollator:
     """
 
     def __init__(
-        self, pre_collate_fn: Callable, encoder_collates: Dict[str, CollateFnType]
+        self,
+        pre_collate_fn: Callable,
+        encoder_collates: Dict[str, CollateFnType],
+        meta_extractors: Dict[str, MetaExtractorFnType],
     ):
         self.pre_collate_fn = pre_collate_fn
         self.encoder_collates = encoder_collates
+        self.meta_extractors = meta_extractors
 
     def pre_encoder_collate(
         self, features: List[Any], ids: List[int] = None, encoder_name: str = None
@@ -35,6 +40,9 @@ class TrainCollator:
         """
         return features
 
+    def process_meta(self, meta: Dict[str, List]) -> Any:
+        return merge_meta(meta)
+
     def __call__(
         self,
         batch: List[Tuple[int, Union[SimilarityPairSample, SimilarityGroupSample]]],
@@ -42,8 +50,10 @@ class TrainCollator:
         ids, features, labels = self.pre_collate_fn(batch)
 
         encoder_collate_result = {}
+        meta = {}
         for encoder_name, collate_fn in self.encoder_collates.items():
             encoder_features = self.pre_encoder_collate(features, ids, encoder_name)
             encoder_collate_result[encoder_name] = collate_fn(encoder_features)
+            meta[encoder_name] = self.meta_extractors[encoder_name](encoder_features)
 
-        return encoder_collate_result, labels
+        return {"data": encoder_collate_result, "meta": self.process_meta(meta)}, labels
